@@ -9,3 +9,11 @@ class Game():
 
 	def add_to_registry(self):
 		Game.registry[self.id] = self
+
+	@classmethod
+	def get_by_id(cls, game_id):
+		return cls.registry[game_id]
+
+	@classmethod
+	def get_all(cls):
+		return cls.registry.values()
